"""
SAX2 driver for the sgmlop parser.

$Id$
"""

version="0.1"

from xml.parsers.sgmllib import SGMLParser
from xml.sax import saxlib
from xml.sax.xmlreader import AttributesImpl,XMLReader
from xml.sax.saxutils import ContentGenerator, prepare_input_source


try:
    import codecs
    def to_xml_string(str,encoding):
        try:
            decoder = codecs.lookup(encoding)[1]
            encoder = codecs.lookup('utf-8')[0]
            return encoder(decoder(str)[0])[0]
        except LookupError:
            return str
except ImportError:
    from xml.unicode.iso8859 import wstring
    def to_xml_string(str,encoding):
        if upper(self._encoding) == 'UTF-8':
            return str
        else:
            return wstring.decode(encoding,str).utf8()
        


class SaxParser(SGMLParser,XMLReader):
    """ Implements IncrementalReader """

    def __init__(self,bufsize = 65536,encoding='UTF-8'):
        XMLReader.__init__(self)
        SGMLParser.__init__(self)
        self.parser = SGMLParser()
        self._bufsize = bufsize
        self._lexical_handler = None
        self._encoding = encoding
        
    def parse(self, source):
        source = prepare_input_source(source)

        self.prepareParser(source)
        file = source.getByteStream()
        buffer = file.read(self._bufsize)
        while buffer != "":
            self.feed(buffer)
            buffer = file.read(self._bufsize)
        self.close()

    def prepareParser(self, source):
        """This method is called by the parse implementation to allow
        the SAX 2.0 driver to prepare itself for parsing."""
        self._cont_handler.startDocument()
        
    def close(self):
        """This method is called when the entire XML document has been
        passed to the parser through the feed method, to notify the
        parser that there are no more data. This allows the parser to
        do the final checks on the document and empty the internal
        data buffer.

        The parser will not be ready to parse another document until
        the reset method has been called.

        close may raise SAXException."""
        SGMLParser.close(self)
        self._cont_handler.endDocument()        

    def _make_attr_dict(self,attr_list):
        d = {}
        cvrt = lambda str,e=self._encoding:to_xml_string(str,e)
        for (a,b) in attr_list:
            d[cvrt(a)]=cvrt(b)
        return d
    
    def unknown_starttag(self,tag,attrs):
        self._cont_handler.startElement(to_xml_string(tag,self._encoding),
                                        AttributesImpl(self._make_attr_dict(attrs)))

    def unknown_endtag(self,tag):
        self._cont_handler.endElement(to_xml_string(tag,self._encoding))

    def handle_data(self,data):
        self._cont_handler.characters(to_xml_string(data,self._encoding))

    def handle_comment(self,data):
        if self._lexical_handler is not None:
            self._lexical_handler.comment(to_xml_string(data,self._encoding))

    def set_property(self,name,value):
        if name == handler.property_lexical_handler:
            self._lexical_handler = value
        else:
            raise SAXNotRecognizedException("Property '%s' not recognized" % name)
    def getProperty(self, name):
        if name == handler.property_lexical_handler:
            return self._lexical_handler
        raise SAXNotRecognizedException("Property '%s' not recognized" % name)

##    def getFeature(self, name):
##        if name == handler.feature_namespaces:
##            return self._namespaces
##        raise SAXNotRecognizedException("Feature '%s' not recognized" % name)

##    def setFeature(self, name, state):
##        if self._parsing:
##            raise SAXNotSupportedException("Cannot set features while parsing")
##        if name == handler.feature_namespaces:
##            self._namespaces = state
##        else:
##            raise SAXNotRecognizedException("Feature '%s' not recognized" %
##                                            name)

    # --- EXPERIMENTAL PYTHON SAX EXTENSIONS

    def get_parser_name(self):
        return "sgmlop"

    def get_parser_version(self):
        return "Unknown"

    def get_driver_version(self):
        return version
    
    def is_validating(self):
        return 0

    def is_dtd_reading(self):
        return 0


from xml.dom.html import HTML_CHARACTER_ENTITIES, HTML_FORBIDDEN_END,HTML_OPT_END,HTML_DTD
from string import strip,upper

class SaxHtmlParser(SaxParser):

    def __init__(self,bufsize = 65536,encoding='iso-8859-1'):
        SaxParser.__init__(self,bufsize,encoding)
        
    def finish_starttag(self, tag, attrs):
        """uses the HTML DTD to automatically generate events
        for missing tags"""

        print 'start',tag,self.stack
        # guess omitted close tags
        while self.stack and \
              upper(self.stack[-1]) in HTML_OPT_END and \
              tag not in HTML_DTD.get(self.stack[-1],[]):
            print '# force end',self.stack[-1]
            self.unknown_endtag(self.stack[-1])
            del self.stack[-1]

        if self.stack and tag not in HTML_DTD.get(self.stack[-1],[]):
            print '*'*30
            print 'Warning : trying to add %s as a child of %s'%\
                  (tag,self.stack[-1])
        
        self.unknown_starttag(tag,attrs)
        if upper(tag) in HTML_FORBIDDEN_END:
            # close immediatly tags for which we won't get and end
            print 'end',tag
            self.unknown_endtag(tag)
            return 0
        else:
            self.stack.append(tag)
        return 1

    def finish_endtag(self, tag):
        print 'end',tag,self.stack
        if tag in HTML_FORBIDDEN_END :
            # do nothing: we've already closed it
            return
        if tag in self.stack:
            while self.stack and self.stack[-1] != tag:
                print '# force end',self.stack[-1]
                self.unknown_endtag(self.stack[-1])
                del self.stack[-1]
            self.unknown_endtag(tag)
            del self.stack[-1]
        else:
            print '*'*30
            print "Warning: I don't see where tag %s was opened"%tag


    def handle_data(self,data):
        if self.stack:
            if '#PCDATA' not in HTML_DTD.get(self.stack[-1],[]) and not strip(data):
                # this is probably ignorable whitespace
                print 'whiteSpace'
                self._cont_handler.ignorableWhitespace(data)
            else:
                print 'data',strip(data)
                self._cont_handler.characters(to_xml_string(data,self._encoding))

    def close(self):
        print 'end document',self.stack
        SGMLParser.close(self)
        self.stack.reverse()
        for tag in self.stack:
            print '# force end',tag
            self.unknown_endtag(tag)
        self.stack = []
        self._cont_handler.endDocument()        




# ----

def create_parser():
    return SaxParser()

def create_html_parser():
    return SaxHtmlParser()
